@@ -6,19 +6,20 @@ component = import_module('sugarbowl.stylize')
 
 class stylize_Test(unittest.TestCase):
 
-    # Tests
+    # Actions
 
     def setUp(self):
         self.stylize = partial(component.stylize, 'test')
 
+    # Tests
+
     def test_1(self):
         result = self.stylize(bold=True)
-        self.assertEqual(result, '[1mtest[m')
+        self.assertEqual(result, '\x1b[1mtest\x1b[0m')
 
     def test_2(self):
         result = self.stylize(foreground='red')
-        self.assertEqual(result, '[31mtest[m')
-
+        self.assertEqual(result, '\x1b[31mtest\x1b[0m')
 
     def test_with_error(self):
         self.assertRaises(ValueError, self.stylize, error='error')
